<center>
    <h1>AIPOSE</h1>
    <b> Library to use pose estimation in your projects easily.</b>
    <br>
    <a href="https://badge.fury.io/py/aipose"><img src="https://badge.fury.io/py/aipose.svg" alt="PyPI version" height="18"></a>
</center>

## Instalation

```bash
pip install aipose
```

## Run demo

Use the following command to run a dem with your cam and yolo-v7-pose-estimator:

```bash
posewebcam
```

## How to use

You can check the section notebooks in the repo in order to check the usage of the library or you can ask in the [Issues section](https://github.com/Tlaloc-Es/aipose/issues).

## References
* https://github.com/RizwanMunawar/yolov7-pose-estimation

## Support

You can do a donation with the following link.

<a href="https://www.buymeacoffee.com/tlaloc" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/default-orange.png" alt="Buy Me A Coffee" height="41" width="174"></a>

Or you can try to make a pull request with your improvements to the repo.
